package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Family;
import com.lantone.qc.pub.model.label.FamilyLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @ClassName : BEH0070
 * @Description : 家族史未描述是否有家族性遗传病史及传染病史
 * @Author : 胡敬
 * @Date: 2020-03-11 15:09
 */
@Component
public class BEH0070 extends QCCatalogue {
    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() != null && inputInfo.getBeHospitalizedDoc().getFamilyLabel() != null) {
            FamilyLabel familyLabel = inputInfo.getBeHospitalizedDoc().getFamilyLabel();
            List<Family> families = familyLabel.getFamilies();
            if (ListUtil.isEmpty(families)) {
                status.set("0");
                return;
            }
            boolean isFindGeneticDiseaseKeyword = false, isFindDiagInfectious = false;
            for (Family family : families) {
                if (family.getGeneticDiseaseKeyword() != null && StringUtil.isNotBlank(family.getGeneticDiseaseKeyword().getName())) {
                    isFindGeneticDiseaseKeyword = true;
                }
                if (family.getDiagInfectious() != null && StringUtil.isNotBlank(family.getDiagInfectious().getName())) {
                    isFindDiagInfectious = true;
                }
                if (isFindGeneticDiseaseKeyword && isFindDiagInfectious) {
                    status.set("0");
                    return;
                }
            }
        }
    }
}