package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Dead;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.entity.Family;
import com.lantone.qc.pub.model.label.FamilyLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @ClassName : BEH0073
 * @Description : 家族中是否有肝炎、结核等病史未描述
 * @Author : 胡敬
 * @Date: 2020-03-11 17:05
 */
@Component
public class BEH0073 extends QCCatalogue {
    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() != null && inputInfo.getBeHospitalizedDoc().getFamilyLabel() != null) {
            FamilyLabel familyLabel = inputInfo.getBeHospitalizedDoc().getFamilyLabel();
            List<Family> families = familyLabel.getFamilies();
            for (Family family : families) {
                if (family.getDiags() == null || family.getDiags().size() == 0) {
                    continue;
                }
                for (Diag diag : family.getDiags()) {
                    if (diag.getName().contains("肝炎") || diag.getName().contains("结核")
                            || diag.getHospitalDiagName().contains("肝炎") || diag.getHospitalDiagName().contains("结核")) {
                        status.set("0");
                        return;
                    }
                }

            }
        }
    }
}