package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR0140
 * @Description : 危重患者、疑难患者、抢救患者查房记录无主任医师/科主任签名
 * @Author : 胡敬
 * @Date: 2020-03-19 19:20
 */
@Component
public class THR0140 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getThreeLevelWardDocs().size() == 0) {
            return;
        }
        if (inputInfo.getDifficultCaseDiscussDocs().size() > 0) {
            processSign(inputInfo, "疑难患者");
        }
        if (inputInfo.getRescueDocs().size() > 0) {
            processSign(inputInfo, "抢救患者");
        }
    }

    private void processSign(InputInfo inputInfo, String message) {
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        for (ThreeLevelWardDoc threeLevelWardDoc : threeLevelWardDocs) {
            Map<String, String> threeLevelWardDocStructureMap = threeLevelWardDoc.getStructureMap();
            String title = threeLevelWardDocStructureMap.get("查房标题");
            String recordDoctor = threeLevelWardDocStructureMap.get("记录医师");
            if (CatalogueUtil.isEmpty(title)) {
                continue;
            }
            if (CatalogueUtil.subTitle(title).contains(Content.director) && CatalogueUtil.isEmpty(recordDoctor)) {
                status.set("-1");
                if (StringUtil.isBlank(message)) {
                    info.set(message);
                } else {
                    info.set(info.get() + "," + message);
                }
                break;
            }
        }
    }
}