package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR0144
 * @Description : 患者出院前无主治医师/副主任医师/主任医师/科主任同意出院的病程记录
 * @Author : 胡敬
 * @Date: 2020-03-19 17:20
 */
@Component
public class THR0144 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getThreeLevelWardDocs().size() > 0) {
            List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
            String lastWardCRoundRecord = "", lastWardRoundTitle = "";
            Date lastWardCRoundDate = null;
            String wardRoundTime, wardCRoundRecord, WardRoundTitle;
            for (ThreeLevelWardDoc threeLevelWardDoc : threeLevelWardDocs) {
                Map<String, String> threeLevelWardDocStructureMap = threeLevelWardDoc.getStructureMap();
                if (StringUtil.isEmpty(threeLevelWardDocStructureMap.get("查房日期"))
                        || StringUtil.isEmpty(threeLevelWardDocStructureMap.get("病情记录"))) {
                    continue;
                }
                wardRoundTime = threeLevelWardDocStructureMap.get("查房日期");
                wardCRoundRecord = threeLevelWardDocStructureMap.get("病情记录");
                WardRoundTitle = threeLevelWardDocStructureMap.get("查房标题");
                Date wardRoundDate = StringUtil.parseDateTime(wardRoundTime);
                if (lastWardCRoundDate == null || (wardRoundDate != null && wardRoundDate.after(lastWardCRoundDate))) {
                    lastWardCRoundDate = wardRoundDate;
                    lastWardCRoundRecord = wardCRoundRecord;
                    lastWardRoundTitle = WardRoundTitle;
                }
            }
            if (lastWardCRoundRecord.contains("出院") && !CatalogueUtil.isEmpty(lastWardRoundTitle)
                    && !CatalogueUtil.subTitle(lastWardRoundTitle).contains(Content.indications)
                    && !CatalogueUtil.subTitle(lastWardRoundTitle).contains(Content.director)) {
                status.set("-1");
            }
        }
    }
}