package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.model.label.ThreeLevelWardLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @ClassName : THR0430
 * @Description : 抢救患者上级医师(副高及以上)查房记录无病情分析及评估
 * @Author : 胡敬
 * @Date: 2020-03-25 14:20
 */
@Component
public class THR0430 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getThreeLevelWardDocs().size() > 0) {
            List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
            for (ThreeLevelWardDoc threeLevelWardDoc : threeLevelWardDocs) {
                if (threeLevelWardDoc.getThreeLevelWardLabel().getSerious() != 3) {
                    continue;
                }
                ThreeLevelWardLabel threeLevelWardLabel = threeLevelWardDoc.getThreeLevelWardLabel();
                if (threeLevelWardLabel.getDiags().size() == 0
                        || StringUtil.isNotBlank(threeLevelWardLabel.getDiagBasisText()) && threeLevelWardLabel.getDiagBasisText().length() < 30
                        || threeLevelWardLabel.getDiffDiag().size() == 0 && StringUtil.isBlank(threeLevelWardLabel.getDiffDiagText())
                        || threeLevelWardLabel.getTreatmentPlans().size() == 0) {
                    status.set("-1");
                    return;
                }
            }
        }
    }
}