package com.lantone.qc.trans.taizhou;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.google.common.collect.Sets;
import com.lantone.qc.pub.model.doc.consultation.ConsultationApplicationDoc;
import com.lantone.qc.pub.model.doc.consultation.ConsultationDoc;
import com.lantone.qc.pub.model.doc.consultation.ConsultationRecordDoc;
import com.lantone.qc.pub.model.doc.consultation.ConsultationResultsDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.taizhou.util.TzXmlUtil;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @Description: 会诊文档生成
 * @author: rengb
 * @time: 2020/3/17 13:22
 */
public class TaiZhouConsultationDocTrans extends ModelDocTrans {

    @Override
    public List<ConsultationDoc> extract(MedrecVo medrecVo) {
        List<ConsultationDoc> retList = Lists.newArrayList();

        Map<String, List<String>> contentMap = (Map) medrecVo.getContent().get("content");
        if (contentMap == null) {
            return retList;
        }

        Map<String, ConsultationRecordDoc> consultationRecordDocMap = getConsultationRecordDocMap(contentMap.get("会诊记录"));
        Map<String, ConsultationResultsDoc> consultationResultsDocMap = getConsultationResultsDocMap(contentMap.get("会诊结果单"));
        Map<String, ConsultationApplicationDoc> consultationApplicationDocMap = getConsultationApplicationDocMap(contentMap.get("会诊申请单"));

        Set<String> consultationNameSet = Sets.newHashSet();
        consultationNameSet.addAll(consultationRecordDocMap.keySet());
        consultationNameSet.addAll(consultationResultsDocMap.keySet());
        consultationNameSet.addAll(consultationApplicationDocMap.keySet());

        consultationNameSet.forEach(consultationName -> {
            ConsultationDoc consultationDoc = new ConsultationDoc();
            consultationDoc.setConsultationName(consultationName);
            consultationDoc.setConsultationRecordDoc(consultationRecordDocMap.get(consultationName));
            consultationDoc.setConsultationResultsDoc(consultationResultsDocMap.get(consultationName));
            consultationDoc.setConsultationApplicationDoc(consultationApplicationDocMap.get(consultationName));
            retList.add(consultationDoc);
        });

        return retList;
    }


    /**************************************************会诊记录*********************************************************/
    private Map<String, ConsultationRecordDoc> getConsultationRecordDocMap(List<String> contents) {
        Map<String, ConsultationRecordDoc> retMap = Maps.newHashMap();
        if (ListUtil.isEmpty(contents)) {
            return retMap;
        }
        int index = 1;
        String consultationName = null;
        for (String content : contents) {
            if (StringUtil.isBlank(content)) {
                continue;
            }
            consultationName = index + "";
            ConsultationRecordDoc consultationRecordDoc = getConsultationRecordDoc(content);
            consultationRecordDoc.setConsultationName(consultationName);
            retMap.put(consultationName, consultationRecordDoc);
            index++;
        }
        return retMap;
    }

    private ConsultationRecordDoc getConsultationRecordDoc(String content) {
        Map<String, String> structureMap = TzXmlUtil.analysisXmlToMap(content, consultationRecord_keyContrasts);

        ConsultationRecordDoc consultationRecordDoc = new ConsultationRecordDoc();
        consultationRecordDoc.setStructureMap(structureMap);

        return consultationRecordDoc;
    }

    private List<String> consultationRecord_keyContrasts = Lists.newArrayList(
            "体检=",
            "审核人=",
            "会诊意见=",
            "事件日期=",
            "医生=",
            "查房医师=",
            "简要病情=",
            "事件基本信息=",
            "会诊执行情况=",
            "职务=",
            "年龄=",
            "临床科室1=",
            "治疗计划和措施=",
            "主诉=",
            "床号=",
            "病人基本信息=",
            "审核日期=",
            "性别=",
            "本人姓名=",
            "查房类别=",
            "会诊查体=",
            "病历号=",
            "会诊科室=",
            "病历日期=",
            "职称=",
            "入院日期=",
            "临床科室=",
            "会诊医生=",
            "病历状态=",
            "审核="
    );


    /**************************************************会诊结果单*******************************************************/
    private Map<String, ConsultationResultsDoc> getConsultationResultsDocMap(List<String> contents) {
        Map<String, ConsultationResultsDoc> retMap = Maps.newHashMap();
        if (ListUtil.isEmpty(contents)) {
            return retMap;
        }
        int index = 1;
        String consultationName = null;
        for (String content : contents) {
            if (StringUtil.isBlank(content)) {
                continue;
            }
            consultationName = index + "";
            ConsultationResultsDoc consultationResultsDoc = getConsultationResultsDoc(content);
            consultationResultsDoc.setConsultationName(consultationName);
            retMap.put(consultationName, consultationResultsDoc);
            index++;
        }
        return retMap;
    }

    private ConsultationResultsDoc getConsultationResultsDoc(String content) {
        Map<String, String> structureMap = TzXmlUtil.analysisXmlToMap(content, consultationResults_keyContrasts);

        ConsultationResultsDoc consultationResultsDoc = new ConsultationResultsDoc();
        consultationResultsDoc.setStructureMap(structureMap);

        return consultationResultsDoc;
    }

    private List<String> consultationResults_keyContrasts = Lists.newArrayList(
            "会诊诊断=",
            "注意事项=",
            "审核人=",
            "事件日期1(会诊申请日期)=",
            "医生=",
            "会诊类别=",
            "事件基本信息=",
            "血压=",
            "年龄=",
            "临床科室1=",
            "病史描述=",
            "会诊到达时间=",
            "床号=",
            "病人基本信息=",
            "审核日期=",
            "性别=",
            "会诊查体=",
            "本人姓名=",
            "病历号=",
            "会诊科室=",
            "病历日期=",
            "记录及建议=",
            "入院日期=",
            "呼吸=",
            "脉搏=",
            "临床科室=",
            "年龄单位=",
            "会诊医生=",
            "申请医生1=",
            "体温=",
            "审核=",
            "病历状态="
    );


    /**************************************************会诊申请单*******************************************************/
    private Map<String, ConsultationApplicationDoc> getConsultationApplicationDocMap(List<String> contents) {
        Map<String, ConsultationApplicationDoc> retMap = Maps.newHashMap();
        if (ListUtil.isEmpty(contents)) {
            return retMap;
        }
        int index = 1;
        String consultationName = null;
        for (String content : contents) {
            if (StringUtil.isBlank(content)) {
                continue;
            }
            consultationName = index + "";
            ConsultationApplicationDoc consultationApplicationDoc = getConsultationApplicationDoc(content);
            consultationApplicationDoc.setConsultationName(consultationName);
            retMap.put(consultationName, consultationApplicationDoc);
            index++;
        }
        return retMap;
    }

    private ConsultationApplicationDoc getConsultationApplicationDoc(String content) {
        Map<String, String> structureMap = TzXmlUtil.analysisXmlToMap(content, consultationApplication_keyContrasts);

        ConsultationApplicationDoc consultationApplicationDoc = new ConsultationApplicationDoc();
        consultationApplicationDoc.setStructureMap(structureMap);

        return consultationApplicationDoc;
    }

    private List<String> consultationApplication_keyContrasts = Lists.newArrayList(
            "注意事项=",
            "审核人=",
            "事件日期=",
            "医生=",
            "会诊类别=",
            "会诊回复=",
            "简要病情=",
            "事件基本信息=",
            "年龄=",
            "床号=",
            "当前诊断=",
            "病人基本信息=",
            "就诊次数=",
            "审核日期=",
            "会诊理由和目的=",
            "性别=",
            "本人姓名=",
            "病历号=",
            "会诊科室=",
            "病历日期=",
            "申请医生=",
            "入院日期=",
            "临床科室=",
            "年龄单位=",
            "会诊医生=",
            "诊治经过=",
            "审核=",
            "病历状态="
    );

}